==> content_feedback-8.x-1.0.tar.gz: content_feedback/src/Form/DeleteContentFeedback.php <==
<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Url;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Extends ConfirmFormBase.
 *
 * @inheritdoc
 */
class DeleteContentFeedback extends ConfirmFormBase {
  protected $id;

  /**
   * Setting FormID.
   *
   * @inheritdoc
   */
  public function getFormId() {
    return 'content_feedback_delete';
  }

  /**
   * Setting Question text.
   *
   * @inheritdoc
   */
  public function getQuestion() {
    return t('Are you sure you want to delete submission %id?', ['%id' => $this->id]);
  }

  /**
   * Setting Confirm Text.
   *
   * @inheritdoc
   */
  public function getConfirmText() {
    return t('Delete');
  }

  /**
   * Setting Cancel Url.
   *
   * @inheritdoc
   */
  public function getCancelUrl() {
    return new Url('content_feedback_list.content');
  }

  /**
   * Building Delete Form.
   *
   * @inheritdoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, $id = '') {
    $this->id = $id;
    $this->exists = ContentFeedbackClass::checkFeedback($this->id);

    if ($this->exists > 0) {
      return parent::buildForm($form, $form_state);
    }
    else {
      throw new NotFoundHttpException();
    }
  }

  /**
   * Submit Form.
   *
   * @inheritdoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $url = Url::fromRoute('content_feedback_list.content');
    ContentFeedbackClass::deleteFeedback($this->id);
    drupal_set_message(t('Content Feedback %id has been deleted.', ['%id' => $this->id]));
    $form_state->setRedirectUrl($url);
  }

}

==> content_feedback-8.x-1.1.tar.gz: content_feedback/src/Form/DeleteContentFeedback.php <==
<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Url;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Extends ConfirmFormBase.
 *
 * @inheritdoc
 */
class DeleteContentFeedback extends ConfirmFormBase {
  protected $id;

  /**
   * Setting FormID.
   *
   * @inheritdoc
   */
  public function getFormId() {
    return 'content_feedback_delete';
  }

  /**
   * Setting Question text.
   *
   * @inheritdoc
   */
  public function getQuestion() {
    return t('Are you sure you want to delete submission %id?', ['%id' => $this->id]);
  }

  /**
   * Setting Confirm Text.
   *
   * @inheritdoc
   */
  public function getConfirmText() {
    return t('Delete');
  }

  /**
   * Setting Cancel Url.
   *
   * @inheritdoc
   */
  public function getCancelUrl() {
    return new Url('content_feedback_list.content');
  }

  /**
   * Building Delete Form.
   *
   * @inheritdoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, $id = '') {
    $this->id = $id;
    $this->exists = ContentFeedbackClass::checkFeedback($this->id);

    if ($this->exists > 0) {
      return parent::buildForm($form, $form_state);
    }
    else {
      throw new NotFoundHttpException();
    }
  }

  /**
   * Submit Form.
   *
   * @inheritdoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $url = Url::fromRoute('content_feedback_list.content');
    ContentFeedbackClass::deleteContentFeedback($this->id);
    drupal_set_message(t('Content Feedback %id has been deleted.', ['%id' => $this->id]));
    $form_state->setRedirectUrl($url);
  }

}
